@@ -2464,6 +2464,11 @@ public class FiniteStateMachine {
 			throw new Exception("State " + stateName
 					+ " does not contains verifyProperty");
 		}
+		
+		if (log.isDebugEnabled()) {
+			log.debug("setVerifyPropertyDigest, state = " + stateName + 
+					", digest = " + digest);
+		}
 
 	}
 
