@@ -906,12 +906,18 @@ public class ReferenceManifest {
 		
 		fis.close();
 		
+		String distroName = prop.getProperty("distro.name");
+		if (distroName == null) {
+			distroName = "unknown";
+		}
+		
 		/* Call */
 		generateKnoppixReferenceManifest(
 				biosImlFilename, 
 				runtimeImlFilename, 
 				grubCdromDir, 
 				grubRootfsDir, 
+				distroName,
 				behaviorModelFilenames, 
 				runtimeModelFilenames);
 		
@@ -936,6 +942,7 @@ public class ReferenceManifest {
 			String runtimeImlFilename, 
 			String grubCdromDir, 
 			String grubRootfsDir,
+			String distroName,
 			String[] behaviorModelFilenames, 
 			String[] runtimeModelFilenames) throws Exception {
 
@@ -985,7 +992,7 @@ public class ReferenceManifest {
 		this.init();
 
 		this.setAttribute(
-				"Knoppix", // TODO
+				distroName, //"Knoppix", // TODO
 				"unknown", // TODO
 				Long.valueOf(date).toString(),
 				"unknown", // TODO
@@ -1087,7 +1094,7 @@ public class ReferenceManifest {
 	}
 
 	
-	private void generateRuntimeReferenceManifestByProp(
+	public void generateRuntimeReferenceManifestByProp(
 			String biosImlFilename, 
 			String runtimeImlFilename, 
 			String modelPropFilename, 
@@ -1138,11 +1145,17 @@ public class ReferenceManifest {
 		
 		fis.close();
 		
+		String distroName = prop.getProperty("distro.name");
+		if (distroName == null) {
+			distroName = "unknown";
+		}
+		
 		/* Call */
 		generateGrubReferenceManifest(
 				biosImlFilename, 
 				grubCdromDir,
 				grubRootfsDir, 
+				distroName,
 				runtimeModelFilenames,
 				null);
 				//behaviorModelFilenames, 
@@ -1165,6 +1178,7 @@ public class ReferenceManifest {
 			String biosImlFilename, // in 1117 SM ADD
 			String grubCdromDir,
 			String localPath, // in
+			String distroName,
 			String[] behaviorModelFilenames, // in
 			String[] runtimeModelFilenames // out
 	) throws Exception {
@@ -1192,11 +1206,11 @@ public class ReferenceManifest {
 		this.init();
 		//rm.selectIIDB(dbIndex); TODO 
 		this.setAttribute(
-				"Lenovo", // TODO
+				distroName,//"unknown", // TODO
 				"unknown", // TODO
 				Long.valueOf(date).toString(),
 				"unknown", // TODO
-				"Lenovo"); // TODO dynamic
+				"unknown"); // TODO dynamic
 	
 		
 		/* Behavior Model*/
